@@ -38,26 +38,30 @@ using json = nlohmann::json;
 namespace anyks {
 	// Токены n-грамм
 	enum class token_t : u_short {
-		num = 2,     // токен арабского или римского числа <num>
-		unk = 3,     // токен неизвестного слова <unk>
-		url = 4,     // токен url адреса <url>
-		null = 0,    // токен неопределённого значения
-		abbr = 5,    // токен аббревиатуры <abbr>
-		date = 6,    // токен даты <date>
-		time = 7,    // токен времени <time>
-		anum = 8,    // токен псевдо-числа <anum>
-		math = 9,    // токен математической операции <math>
-		start = 1,   // токен начала предложения <s>
-		rnum = 10,   // токен римского числа (не используется в чистом виде)
-		specl = 11,  // токен спец-символа <specl>
-		aprox = 12,  // токен приблизительного числа <aprox>
-		range = 13,  // токен диапазона чисел <range>
-		score = 14,  // токен числового счёта <score>
-		dimen = 15,  // токен габаритных размеров <dimen>
-		fract = 16,  // токен числовой дроби <fract>
-		punct = 17,  // токен знака пунктуации <punct>
-		isolat = 18, // токен знака изоляции <isolat>
-		finish = 19  // токен конеца предложения </s>
+		num = 2,      // токен арабского или римского числа <num>
+		unk = 3,      // токен неизвестного слова <unk>
+		url = 4,      // токен url адреса <url>
+		null = 0,     // токен неопределённого значения
+		abbr = 5,     // токен аббревиатуры <abbr>
+		date = 6,     // токен даты <date>
+		time = 7,     // токен времени <time>
+		anum = 8,     // токен псевдо-числа <anum>
+		math = 9,     // токен математической операции <math>
+		start = 1,    // токен начала предложения <s>
+		rnum = 10,    // токен римского числа (не используется в чистом виде)
+		greek = 11,   // токен символа греческого алфавита <greek>
+		route = 12,   // токен символа направления (стрелок) <route>
+		specl = 13,   // токен спец-символа <specl>
+		aprox = 14,   // токен приблизительного числа <aprox>
+		range = 15,   // токен диапазона чисел <range>
+		score = 16,   // токен числового счёта <score>
+		dimen = 17,   // токен габаритных размеров <dimen>
+		fract = 18,   // токен числовой дроби <fract>
+		punct = 19,   // токен знака пунктуации <punct>
+		pcards = 20,  // токен символа игральных карт <pcards>
+		isolat = 21,  // токен знака изоляции <isolat>
+		finish = 22,  // токен конеца предложения </s>
+		currency = 23 // токен символа мировой валюты <currency>
 	};
 	// Тип данных пары целых значений
 	typedef pair <size_t, size_t> pair_t;
@@ -69,6 +73,8 @@ namespace anyks {
 			// Тип функции внешнего токенизатора
 			typedef function <void (const wstring &, function <const bool (const wstring &, const vector <string> &, const bool, const bool)>)> tokenz_t;
 		private:
+			// Разрешение использовать символы ударения
+			bool stress;
 			// Объект идентификатора
 			idw_t wrdId;
 			// Список аббревиатур
@@ -79,6 +85,14 @@ namespace anyks {
 			// Объект алфавита
 			const alphabet_t * alphabet;
 		public:
+			/**
+			 * allowStress Метод разрешения, использовать ударение в словах
+			 */
+			void allowStress() noexcept;
+			/**
+			 * disallowStress Метод запрещения использовать ударение в словах
+			 */
+			void disallowStress() noexcept;
 			/**
 			 * setAbbr Метод добавления аббревиатуры
 			 * @param word слово для добавления
